@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1300';
+our $VERSION = '0.1400';
 
 use strict;
 use warnings;
@@ -132,11 +132,10 @@ sub _now { # Return hour, minute, second.
 sub number_ranger {
     my %args = @_;
     # Set defaults.
-    $args{start}  ||= 0;
-    $args{end}    ||= NDATA;
-    $args{prec}   ||= PREC;
-    $args{random} ||= 1;
-    $args{N}      ||= NDATA;
+    $args{start}  //= 1;
+    $args{end}    //= NDATA;
+    $args{prec}   //= PREC;
+    $args{random} //= 1;
 
     # Bucket for our result list.
     my @results;
@@ -144,19 +143,23 @@ sub number_ranger {
     # Do we want random numbers?
     if ($args{random}) {
         # Roll!
-        for(1 .. $args{N}) {
+        for($args{start} .. $args{end}) {
             # Get our random candidate.
             my $x = rand($args{end});
             # Make sure it is above the start value.
             while ($x < $args{start}) {
                 $x = rand($args{end});
             }
+            $x = sprintf '%.*f', $args{prec}, $x;
             push @results, $x;
         }
     }
     else {
-        # Use a simple sequence of integers.
+        # Use a contiguous sequence.
         @results = ($args{start} .. $args{end});
+        for ( @results ) {
+            $_ = sprintf '%.*f', $args{prec}, $_;
+        }
     }
 
     return \@results;
@@ -235,8 +238,8 @@ sub distributor {
     my %args = @_;
     # Set defaults.
     $args{type} ||= 'u';
-    $args{prec} ||= PREC;
-    $args{dof}  ||= DOF;
+    $args{prec} //= PREC;
+    $args{dof}  //= DOF;
     $args{N}    ||= NDATA;
 
     # Separate numerator/denominator for F degs-of-freedm.
@@ -248,23 +251,28 @@ sub distributor {
 
     # Roll!
     for(1 .. $args{N}) {
+        my $x;
+
         # Select distribution.
         if ($args{type} eq 'c') {
             # Chi-squared
-            push @results, Statistics::Distributions::chisqrdistr($args{dof}, rand);
+            $x = Statistics::Distributions::chisqrdistr($args{dof}, rand);
         }
         elsif ($args{type} eq 's') {
             # Student's T
-            push @results, Statistics::Distributions::tdistr($args{dof}, rand);
+            $x = Statistics::Distributions::tdistr($args{dof}, rand);
         }
         elsif ($args{type} eq 'f') {
             # F distribution
-            push @results, Statistics::Distributions::fdistr($args{dof}, $e, rand);
+            $x = Statistics::Distributions::fdistr($args{dof}, $e, rand);
         }
         else {
             # Normal
-            push @results, Statistics::Distributions::udistr(rand);
+            $x = Statistics::Distributions::udistr(rand);
         }
+
+        $x = sprintf '%.*f', $args{prec}, $x;
+        push @results, $x;
     }
 
     return \@results;
@@ -385,7 +393,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1300
+version 0.1400
 
 =head1 SYNOPSIS
 
@@ -393,8 +401,8 @@ version 0.1300
   # * Call each function below with Mock::Populate::foo(...
   my $n      = 5;
   my $offset = 11;
-  my $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0, N => $n);
-  my $money  = number_ranger(start => 1000, end => 5000, prec => 2, random => 1, N => $n);
+  my $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0);
+  my $money  = number_ranger(start => 1000, end => 5000, prec => 2, random => 1);
   my $create = date_ranger(start => '1900-01-01', end => '2020-12-31', N => $n);
   my $modify = date_modifier($offset, @$create);
   my $times  = time_ranger(stamp => 1, start => '01:02:03', end =>'23:59:59', N => $n);
@@ -467,18 +475,16 @@ determines if a time-stamp or the number of seconds should be returned.
     end    => $end,
     prec   => $prec,
     random => $random,
-    N      => $n
   );
 
 Return a list of B<N> random numbers within a range.  The B<start>, B<end>,
-B<prec>ision, whether we want B<random> or sequential numbers, and the desired
-number of data-points are all optional.  The defaults are:
+B<prec>ision, and whether we want B<random> or sequential numbers are all
+optional.  The defaults are:
 
-  start:     0
-  end:       9
+  start:     1
+  end:       10
   precision: 2
-  random:    1
-  N:         10
+  random:    1 (boolean)
 
 =head2 name_ranger()
 
